/* A note from the programmer: This program was written over many hours 
 * even though it is open source I would greatly appreciate any credit or shoutouts if you
 * use my code. Cheers -Garnet Koebel
 * 
 * Program Title: Gesture Control Display Controller 
 * Program Author: Garnet Koebel
 * Program Description: This program allows for external displays to be connected to the
 * OS-GCP system to view live sensor readings
 */

/*
 * //NOTE: Will have to modify display functions to accomadate multiple displays (add addressing)
 A4 = SDA
 A5 = SCL
 */
#include <SPI.h>
#include <Wire.h>
#include <SoftwareSerial.h>
#include <Adafruit_GFX.h>
#include <Adafruit_SSD1306.h>
#include <string.h>
#include <stdio.h>

#define OLED_RESET 4
Adafruit_SSD1306 display(OLED_RESET);

#define NUMFLAKES 10
#define XPOS 0
#define YPOS 1
#define DELTAY 2


#define LOGO_HEIGHT 32 
#define LOGO_WIDTH  32

const unsigned char PROGMEM KS_LOGO_OLED [] = {
0x00, 0x03, 0xE0, 0x00, 0x00, 0x3F, 0xFE, 0x00, 0x00, 0xFF, 0xFF, 0x80, 0x01, 0xFF, 0xFF, 0xC0,
0x07, 0xFF, 0xFF, 0xF0, 0x0F, 0xFF, 0xFF, 0xF8, 0x0F, 0xFF, 0xFF, 0xF8, 0x1F, 0xFF, 0xFF, 0xFC,
0x3F, 0xFF, 0xFF, 0xFE, 0x3F, 0xBE, 0xC0, 0x7E, 0x7F, 0xBD, 0xDF, 0x7F, 0x7F, 0xBD, 0xDF, 0x7F,
0x7F, 0xBB, 0xDF, 0xFF, 0x7F, 0xB7, 0xDF, 0xFF, 0x7F, 0xB7, 0xDF, 0xFF, 0xFF, 0xAF, 0xC7, 0xFF,
0xFF, 0x8F, 0xF1, 0xFF, 0xFF, 0xB7, 0xF8, 0x7F, 0x7F, 0xB7, 0xFE, 0x7F, 0x7F, 0xBB, 0xFF, 0x7F,
0x7F, 0xB9, 0xDF, 0x7F, 0x7F, 0xBD, 0xDF, 0x7F, 0x7F, 0xBE, 0xDF, 0x7F, 0x3F, 0xBE, 0x00, 0x7E,
0x3F, 0xFF, 0xFF, 0xFE, 0x1F, 0xFF, 0xFF, 0xFC, 0x0F, 0xFF, 0xFF, 0xF8, 0x0F, 0xFF, 0xFF, 0xF8,
0x07, 0xFF, 0xFF, 0xF0, 0x01, 0xFF, 0xFF, 0xC0, 0x00, 0xFF, 0xFF, 0x80, 0x00, 0x3F, 0xFE, 0x00
};

#if (SSD1306_LCDHEIGHT != 32)
#error("Height incorrect, please fix Adafruit_SSD1306.h!");
#endif

SoftwareSerial displaySerial(10, 11); //RX, TX
int readingRecieveArr[] = {1, 2, 3, 4, 5};
char startBit = '?';
char stopBit = '!';
bool debugMode = true;
bool activity = false;
bool displayStatus = 0;
int timer = 0;

void setup() {
  Serial.begin(9600); //Start Debug Serial
  displaySerial.begin(9600); //Start transarduino serial
  display.begin(SSD1306_SWITCHCAPVCC, 0x3C);  // initialize with the I2C addr 0x3C (for the 128x32)
  //Initialize gestures
  initGestures();
  
  // Clear the buffer.
  display.clearDisplay();
  display.setTextSize(1);
  display.setTextColor(WHITE);
  display.setCursor(0,0);

  //Display Logo
  bootupLogo();
}

void loop() {
  debugPrint(displayStatus);
  debugPrint(digitalRead(2));
 // pwrSv(500);
  receiveData();
  updateDisplay();
}

void toggleState() {
  if (displayStatus) {
    shutdownDisplay();
  } else if (!displayStatus) {
    startDisplay();
  }
}
//Add function to clear screen every couple cycles

